package COVID19 "Package containing the example model"
  model COVID19Model "Model for the spread of an infectious disease"
    extends HighSchoolBiology.HerdImmunity.Exercises.PolicyImpactModel;
    annotation(preferredView = "info", __Wolfram(PlotSet(plots = {Plot(name = "Population Graph with captions", identifier = "d4d8c", preferred = true, caption = "At the end of the simulated duration, the total numbers of susceptible, infected and recovered are %{susceptible.n},%{infected.n} and %{recovered.n}, respectively.
Literature on the SIR model can be found here: %[SIR model for the spread of disease.](https://www.maa.org/press/periodicals/loci/joma/the-sir-model-for-spread-of-disease-the-differential-equation-model)", subPlots = {SubPlot(curves = {Curve(x = time, y = susceptible.n, legend = "susceptible"), Curve(x = time, y = infected.n, legend = "infected"), Curve(x = time, y = recovered.n, legend = "recovered")}, label = Label(y = "Number of people"))})})), experiment(__Wolfram_DisplayTimeUnit = "d"), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Ellipse(visible = true, lineColor = {75, 138, 73}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, -100}, {100, 100}}), Polygon(visible = true, lineColor = {0, 0, 255}, fillColor = {75, 138, 73}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, points = {{-36, 60}, {64, 0}, {-36, -60}, {-36, 60}})}), Documentation(info = "<html>


    <p>
During a pandemic, governments implement various policies that typically would decrease the exponential growth rate. This example shows what happens without any policy implementation and how timing is very important. The ambition is not to give any precise numbers, but to make it easier to understand how simple yet at the same time complicated it is to control a pandemic.
</p>

    <p>
The COVID-19 model used in this example is based on the SIR (susceptible, infectious, recovered) model. The SIR model was developed by Kermack and McKendrick in the early 1900s and is one of the most well-known models for studying infectious diseases within populations. Since its development, there have been many adaptations of the model, allowing it to be used in a wide variety of settings and contexts.
</p><p>
<img src=\"modelica://COVID19/DocumentationFiles/Model.png\" alt=\"Model\"/>
</p>
    <h4>Analysis</h4>
    <p>
Use the Locators to introduce policy measures. A policy impact factor represents effect of measures such as lock down and social distancing. Value of more than 1 reduces the effective reproduction number (R0hat). Observe the difference between a no-policy model and a model with policy. The dashed lines represent the results with policy.
</p><p>
<img src=\"modelica://COVID19/DocumentationFiles/Analysis.png\" alt=\"Analysis\"/>
</p>


<p>In order to get the full experience of this example, you need a desktop Wolfram Language product. A free trial download is available at&nbsp;<a href=\"http://www.wolfram.com/mathematica/trial/\">www.wolfram.com/mathematica/trial/</a></p>

<p>For the full example, open the accompanying notebook <a href=\"modelica://COVID19.COVID19Model/COVID19.nb\">COVID19.nb</a>.</p>

</html>"), Diagram(coordinateSystem(extent = {{-90, -60}, {80, 55}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
  end COVID19Model;
  annotation(preferredView = "info", uses(Modelica(version = "4.0.0"), HighSchoolBiology(version = "2.0")), __Wolfram(openClass = COVID19.COVID19Model), Documentation, Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {111, 0, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-90.0, -90.0}, {90.0, 90.0}}, radius = 25), Text(visible = true, origin = {12.0, 20.8333}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-102.0, -70.8333}, {78.0, 29.1667}}, textString = "Ex", fontName = "Arial")}));
end COVID19;
